==> astrotool-0.0.8.tar.gz: astrotool-0.0.8/astrotool/__init__.py <==
#!/bin/env python
# -*- coding: utf-8 -*-
# SPDX-License-Identifier: EUPL-1.2

#  Copyright (c) 2019-2022  Marc van der Sluys - marc.vandersluys.nl
#   
#  This file is part of the AstroTool Python package,
#  see: http://astro.ru.nl/~sluys/AstroTool/
#   
#  AstroTool has been developed by Marc van der Sluys of the Department of Astrophysics at the Radboud
#  University Nijmegen, the Netherlands and the department of Sustainable energy of the HAN University of
#  applied sciences in Arnhem, the Netherlands.
#   
#  This is free software: you can redistribute it and/or modify it under the terms of the
#  European Union Public Licence 1.2 (EUPL 1.2).
#  
#  This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
#  without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#  See the EU Public Licence for more details.
#  
#  You should have received a copy of the European Union Public Licence along with this code.
#  If not, see <https://www.eupl.eu/1.2/en/>.


"""AstroTool package
=================

AstroTool is a Python package to do basic astronomical calculations in Python or on the command line.  The
package can be used under the conditions of the EUPL 1.2 licence.  These pages contain the API documentation.
For more information on the Python package, licence, source code and data files, see the `AstroTool homepage
<http://astro.ru.nl/~sluys/AstroTool/>`_.

"""


name = 'astrotool'

from .coordinates import *
from .date_time import *

==> astrotool-0.0.23.tar.gz: astrotool-0.0.23/astrotool/__init__.py <==
#!/bin/env python
# -*- coding: utf-8 -*-
# SPDX-License-Identifier: EUPL-1.2

#  Copyright (c) 2019-2025  Marc van der Sluys - marc.vandersluys.nl
#   
#  This file is part of the AstroTool Python package,
#  see: https://www.nikhef.nl/~sluys/AstroTool/
#   
#  AstroTool has been developed by Marc van der Sluys of the Department of Physics at Utrecht
#  University in the Netherlands, and the Netherlands Institute for Nuclear and High-Energy Physics (Nikhef)
#  in Amsterdam.
#   
#  This is free software: you can redistribute it and/or modify it under the terms of the
#  European Union Public Licence 1.2 (EUPL 1.2).
#  
#  This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
#  without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#  See the EU Public Licence for more details.
#  
#  You should have received a copy of the European Union Public Licence along with this code.
#  If not, see <https://www.eupl.eu/1.2/en/>.


"""AstroTool package
=================

AstroTool is a Python package to do basic astronomical calculations in Python or on the command line.  The
package can be used under the conditions of the EUPL 1.2 licence.  These pages contain the API documentation.
For more information on the Python package, licence, source code and data files, see the `AstroTool homepage
<https://www.nikhef.nl/~sluys/AstroTool/>`_.

"""


name = 'astrotool'

from .angles import *
from .coordinates import *
from .date_time import *
from .visibility import *
